Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3448)

Unified Diff: chrome/renderer/spellchecker/hunspell_engine.h

Issue 11445002: Sync user's custom spellcheck dictionary (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Add server-side size limit tests Created 7 years, 12 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/renderer/spellchecker/hunspell_engine.h
diff --git a/chrome/renderer/spellchecker/hunspell_engine.h b/chrome/renderer/spellchecker/hunspell_engine.h
index 981c48e30a3c582cd90ea2da36c5a5d602556d7f..5dfcb23fbab01e0e738f60f49b963e67be8b3bb2 100644
--- a/chrome/renderer/spellchecker/hunspell_engine.h
+++ b/chrome/renderer/spellchecker/hunspell_engine.h
@@ -30,19 +30,20 @@ class HunspellEngine : public SpellingEngine {
virtual bool CheckSpelling(const string16& word_to_check, int tag) OVERRIDE;
virtual void FillSuggestionList(const string16& wrong_word,
std::vector<string16>* optional_suggestions) OVERRIDE;
- virtual void OnWordAdded(const std::string& word) OVERRIDE;
- virtual void OnWordRemoved(const std::string& word) OVERRIDE;
+ virtual void OnWordsAddedRemoved(
groby-ooo-7-16 2013/01/10 19:53:03 "OnCustomDictionaryChanged" instead?
please use gerrit instead 2013/01/12 02:50:46 Good point. I had AddedRemoved everywhere. Changed
+ const std::vector<std::string>& words_added,
+ const std::vector<std::string>& words_removed) OVERRIDE;
private:
// Initializes the Hunspell dictionary, or does nothing if |hunspell_| is
// non-null. This blocks.
void InitializeHunspell();
- // Add the given custom word to |hunspell_|.
- void AddWordToHunspell(const std::string& word);
+ // Add the given custom words to |hunspell_|.
+ void AddWordsToHunspell(const std::vector<std::string>& words);
- // Remove the given custom word from |hunspell_|.
- void RemoveWordFromHunspell(const std::string& word);
+ // Remove the given custom words from |hunspell_|.
+ void RemoveWordsFromHunspell(const std::vector<std::string>& words);
// We memory-map the BDict file.
scoped_ptr<file_util::MemoryMappedFile> bdict_file_;
@@ -54,7 +55,7 @@ class HunspellEngine : public SpellingEngine {
base::PlatformFile file_;
- // This flags is true if we have been intialized.
+ // This flags is true if we have been initialized.
// The value indicates whether we should request a
// dictionary from the browser when the render view asks us to check the
// spelling of a word.

Powered by Google App Engine
This is Rietveld 408576698